@@ -1,7 +1,7 @@
 library("adjclust")
 
 check_snp <- function() {
-  if (!requireNamespace("snpStats")) {
+  if (!require("snpStats")) {
     skip("'snpStats' package not available")
   }
 }
@@ -21,13 +21,13 @@ test_that("snpClust gives results identical to those of adjclust 0.3.0", {
   data("ld.example", package = "snpStats")
   h <- 100
     
-  ld.ceph <- ld(ceph.1mb, depth = h, stats = "R.squared")
+  ld.ceph <- snpStats::ld(ceph.1mb, depth = h, stats = "R.squared")
     
   p <- ncol(ceph.1mb)
   nSamples <- nrow(ceph.1mb)
   h <- 100
   ceph.1mb[4,286]@.Data[1,1] <- as.raw(3) ## to avoid NaNs
-  ld.ceph <- ld(ceph.1mb, depth = h, stats = "R.squared")
+  ld.ceph <- snpStats::ld(ceph.1mb, depth = h, stats = "R.squared")
   ld.ceph <- round(ld.ceph, digits = 10)
     
   ## diagonal elements are 0 
